@@ -46,13 +46,14 @@ def cli(ctx):
         ctx.obj.service = ctx.obj.client.service("query")
 
 
-from nextcodecli.commands.query.run import run, project, info, results, cancel, list_queries, progress, details
+from nextcodecli.commands.query.run import run, project, info, download, results, cancel, list_queries, progress, details
 from nextcodecli.commands.query.templates import templates
 from nextcodecli.commands.query.status import status
 
 cli.add_command(run)
 cli.add_command(project)
 cli.add_command(info)
+cli.add_command(download)
 cli.add_command(results)
 cli.add_command(cancel)
 cli.add_command(progress)
