@@ -219,6 +219,28 @@ def results(ctx, query_id, output_file, limit, filt, sort, is_json):
     get_results(qry, limit, filt, sort, output_file, is_json)
 
 
+@click.command()
+@click.argument('query_id', nargs=1)
+@click.argument('filename', nargs=1)
+@click.pass_context
+@check_project
+def download(ctx, query_id, filename):
+    """
+    Retrieve results from a completed GOR query to file.
+    """
+    svc = ctx.obj.service
+
+    qry = svc.get_query(query_id)
+    if not qry.done:
+        abort("Query has status %s which is not DONE" % qry.status)
+
+    line_count = qry.stats.get("line_count")
+    click.secho(f"Downloading {line_count} lines to file...", bold=True)
+
+    ret = qry.download_results(filename)
+    click.secho(f"Query results have been downloaded to {ret}", bold=True)
+
+
 @click.command()
 @click.argument('query_id', nargs=1)
 @click.pass_context
