@@ -312,6 +312,20 @@ def resume(ctx):
     echo("Executing %s..." % ' '.join(cmd))
     subprocess.call(cmd)
 
+@job.command(help="View parameters for this job.")
+@option('--raw', 'is_raw', is_flag=True, help='Dump raw json response from endpoint')
+@pass_context
+def params(ctx, is_raw):
+    workflow_job = ctx.obj.job
+    params = ctx.obj.session.get(workflow_job.links['params']).json()
+    if is_raw:
+        echo(dumps(params))
+        return
+    for k, v in params.items():
+        vv = v
+        if isinstance(vv, str) and len(vv) > 100:
+            vv = vv[:100] + "..."
+        print_tab(k, vv)
 
 @job.command(help="View logs associated with a job. Choose the log group to stream.")
 @argument('log_group', default='')
